ams.opt.omodel.OModelBase
=========================

.. currentmodule:: ams.opt.omodel

.. autoclass:: OModelBase

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: _generated/

   
       
       
          ~OModelBase.evaluate
       
       
          ~OModelBase.finalize
       
       
          ~OModelBase.init
       
       
          ~OModelBase.parse
       
       
          ~OModelBase.update
       
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: _generated/

   
      ~OModelBase.class_name
      ~OModelBase.initialized
   
   